@@ -285,7 +285,7 @@ displaytextitem(Item *item)
 		return;
 	case 0:
 		parent = 0;
-		if (!(pagerin = popen("$PAGER", "we")))
+		if (!(pagerin = popen("$PAGER", "w")))
 			_exit(1);
 		fputs(item->raw, pagerin);
 		exit(pclose(pagerin));
@@ -951,6 +951,12 @@ cleanup(void)
 		uicleanup();
 }
 
+void
+sighandler(int signo)
+{
+	exit(128 + signo);
+}
+
 static void
 setup(void)
 {
@@ -971,7 +977,7 @@ setup(void)
 
 	sigemptyset(&sa.sa_mask);
 	sa.sa_flags = SA_RESTART;
-	sa.sa_handler = exit;
+	sa.sa_handler = sighandler;
 	sigaction(SIGINT, &sa, NULL);
 	sigaction(SIGHUP, &sa, NULL);
 	sigaction(SIGTERM, &sa, NULL);
